@@ -10,8 +10,5 @@
   packageStartupMessage("")
   packageStartupMessage("Use sombreroGUI() to start the Graphical Interface.")
   packageStartupMessage("")
-  packageStartupMessage("Warning! This package has been implemented (mostly) by girls.")
-  packageStartupMessage("Default colors may not be suited for men.")
-  packageStartupMessage("")
   packageStartupMessage("***********************************************************")
 }
